@@ -130,7 +130,7 @@ class NavParser:
     def break_NMEA_into_blocks(self, nmea_lines):
         blocks = []
         for line in nmea_lines:
-            self._nmea_block_buffer += f'{line}\n'
+            self._nmea_block_buffer += line
             self._nmea_buffer_flags = {k: True if k in line else v for k, v in self._nmea_buffer_flags.items()}
             for flag in self._nmea_buffer_flags:
                 self._nmea_buffer_flags[flag] = True if flag in line else self._nmea_buffer_flags[flag]
@@ -148,11 +148,11 @@ class NavParser:
             if len(data) <= 6:
                 continue
             sentenceID = data[0][3:]  # $GPGGA -> GGA
-            if sentenceID == NMEASentectID.GGA:
+            if sentenceID == NMEASentectID.GGA.value:
                 GGA = data
-            if sentenceID == NMEASentectID.RMC:
+            if sentenceID == NMEASentectID.RMC.value:
                 RMC = data
-            if sentenceID == NMEASentectID.VTG:
+            if sentenceID == NMEASentectID.VTG.value:
                 VTG = data
         if not (GGA and RMC and VTG and GGA[0][1:3] == RMC[0][1:3] == VTG[0][1:3]):
             raise exceptions.InputError("illegal NMEA block")
